@@ -7,6 +7,7 @@
 #' @export
 #' @importFrom xml2 read_html
 #' @importFrom rvest html_node html_text
+#' @importFrom httr GET content
 #' @examples
 #' \donttest{
 #'   print(cate_list_url_ex)
@@ -15,7 +16,7 @@
 
 getMaxPageNum <- function(turl = url, max = 100) {
   ifmaxUrl <- paste0(turl, "&page=", max)
-  hobj <- xml2::read_html(ifmaxUrl)
+  hobj <- read_html(httr::content(httr::GET(ifmaxUrl), "text"))
   noContent <-  rvest::html_node(hobj, "div.no_content")
   if (class(noContent) == "xml_node") {
     return("no result")
